
#include "UART.H"
	


typedef unsigned char BYTE;
typedef unsigned int WORD;

#define FOSC 11059200L*2          //系统频率
#define BAUD 115200             //串口波特率

#define NONE_PARITY     0       //无校验
#define ODD_PARITY      1       //奇校验
#define EVEN_PARITY     2       //偶校验
#define MARK_PARITY     3       //标记校验
#define SPACE_PARITY    4       //空白校验

#define PARITYBIT NONE_PARITY   //定义校验位





#define S1_S0 0x40              //P_SW1.6
#define S1_S1 0x80              //P_SW1.7



//bit busy;
bit busy=0;

void init_uart(void)
{
	/*
	ACC = P_SW1;
    ACC &= ~(S1_S0 | S1_S1);    //S1_S0=0 S1_S1=0
    P_SW1 = ACC;                //(P3.0/RxD, P3.1/TxD)
	*/
 ACC = P_SW1;
  ACC &= ~(S1_S0 | S1_S1);    //S1_S0=1 S1_S1=0
  ACC |= S1_S0;               //(P3.6/RxD_2, P3.7/TxD_2)
  P_SW1 = ACC;  


#if (PARITYBIT == NONE_PARITY)
    SCON = 0x50;                //8位可变波特率
#elif (PARITYBIT == ODD_PARITY) || (PARITYBIT == EVEN_PARITY) || (PARITYBIT == MARK_PARITY)
    SCON = 0xda;                //9位可变波特率,校验位初始为1
#elif (PARITYBIT == SPACE_PARITY)
    SCON = 0xd2;                //9位可变波特率,校验位初始为0
#endif

    T2L = (65536 - (FOSC/4/BAUD));   //设置波特率重装值
    T2H = (65536 - (FOSC/4/BAUD))>>8;
    AUXR = 0x14;                //T2为1T模式, 并启动定时器2
    AUXR |= 0x01;               //选择定时器2为串口1的波特率发生器
    ES = 1;                     //使能串口1中断
    EA = 1;
}

/*----------------------------
UART 中断服务程序
-----------------------------*/
char rec_buf[80];
int rec_count=0;
/*
void Uart() interrupt 4 using 1
{
	
    if (RI)
    {
			 
        RI = 0;                 //清除RI位
       // P0 = SBUF;              //P0显示串口数据
					rec_buf[rec_count++]= SBUF;
			if(rec_count<80)
			{
				if((rec_buf[rec_count-1]=='\n')||(rec_buf[rec_count-2]=='\r'))
				{
					busy=1;
				}
			}
			else{
				rec_count=0;
				}
        //P22 = RB8;              //P2.2显示校验位
    }
    if (TI)
    {
        TI = 0;                 //清除TI位
        busy = 0;               //清忙标志		
    }
}*/

void Uart() interrupt 4 using 1
{
	
    if (RI)
    {
        RI = 0;                 //清除RI位
       // P0 = SBUF;              //P0显示串口数据
					rec_buf[rec_count++]= SBUF;
			if(rec_count<80)
			{
				if((rec_buf[rec_count-1]=='\n')||(rec_buf[rec_count-2]=='\r'))
				{
					busy=1;
				}
			}
			else{
				rec_count=0;
				}
        //P22 = RB8;              //P2.2显示校验位
    }
    if (TI)
    {
        TI = 0;                 //清除TI位
        busy = 0;               //清忙标志		
    }
}

/*----------------------------
发送串口数据
----------------------------*/
/*
void SendData(BYTE dat)
{
    while (busy);               //等待前面的数据发送完成
    ACC = dat;                  //获取校验位P (PSW.0)
    if (P)                      //根据P来设置校验位
    {
#if (PARITYBIT == ODD_PARITY)
        TB8 = 0;                //设置校验位为0
#elif (PARITYBIT == EVEN_PARITY)
        TB8 = 1;                //设置校验位为1
#endif
    }
    else
    {
#if (PARITYBIT == ODD_PARITY)
        TB8 = 1;                //设置校验位为1
#elif (PARITYBIT == EVEN_PARITY)
        TB8 = 0;                //设置校验位为0
#endif
    }
    busy = 1;
    SBUF = ACC;                 //写数据到UART数据寄存器
}
*/
/*----------------------------
发送字符串
----------------------------*/
/*
void SendString(char *s)
{
    while (*s)                  //检测字符串结束标志
    {
        SendData(*s++);         //发送当前字符
    }
}
*/
void at_uart_send_str(unsigned char *str)//发送at字符串到串口
{
  unsigned char *st_p=str;
  do{
     SBUF=*st_p;
	 st_p++;
	 Delay2(1);
	}while(*st_p);
	SBUF='\r';
	Delay2(1);
	SBUF='\n';
	Delay2(1);
}
